@@ -11,7 +11,7 @@ from xml.etree import ElementTree
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC
 
-from requests import Session
+from requests import exceptions, Session
 
 from .errors import InvalidError, LoginError, NotLoggedInError
 from .fritzhomedevice import FritzhomeDevice
@@ -36,6 +36,8 @@ class Fritzhome(object):
         self._password = password
         self._session = Session()
         self._ssl_verify = ssl_verify
+        self._has_getdeviceinfos = True
+        self._has_txbusy = True
 
     def _request(self, url, params=None, timeout=10):
         """Send a request with parameters."""
@@ -199,12 +201,31 @@ class Fritzhome(object):
 
     def wait_device_txbusy(self, ain, retries=10):
         """Wait for device to finish command execution."""
+        if not self._has_txbusy:
+            return True
+
         for _ in range(retries):
-            plain = self.get_device_infos(ain)
-            dom = ElementTree.fromstring(plain)
+            if self._has_getdeviceinfos:
+                try:
+                    # getdeviceinfos was added in FritzOS 7.24
+                    plain = self.get_device_infos(ain)
+                    dom = ElementTree.fromstring(plain)
+                except exceptions.HTTPError:
+                    _LOGGER.debug("fallback to getdevicelistinfos")
+                    self._has_getdeviceinfos = False
+
+            if not self._has_getdeviceinfos:
+                dom = self.get_device_element(ain)
+
             txbusy = dom.findall("txbusy")
+            if not txbusy:
+                # txbusy was added in FritzOS 7.20
+                self._has_txbusy = False
+                return True
+
             if txbusy[0].text == "0":
                 return True
+
             time.sleep(0.2)
         return False
 
@@ -282,7 +303,7 @@ class Fritzhome(object):
 
     def _get_temperature(self, ain, name):
         plain = self._aha_request(name, ain=ain, rf=float)
-        return (plain - 16) / 2 + 8
+        return plain / 2
 
     def get_target_temperature(self, ain):
         """Get the thermostate target temperature."""
@@ -290,11 +311,11 @@ class Fritzhome(object):
 
     def set_target_temperature(self, ain, temperature, wait=False):
         """Set the thermostate target temperature."""
-        temp = int(16 + ((float(temperature) - 8) * 2))
+        temp = int(temperature * 2)
 
-        if temp < min(range(16, 56)):
+        if temp < 16:
             temp = 253
-        elif temp > max(range(16, 56)):
+        elif temp > 56:
             temp = 254
 
         self._aha_request("sethkrtsoll", ain=ain, param={"param": temp})
